Use Case:  Configure personalization options
============================================

Actor
-----

Site Visitor

Overview
--------

One of the benefits of becoming a member of a CMF Site is the ability to
create persistent personalizations of the way the site is displayed: in
particular, this personalization allows the member to select from among the
skins which have been configured by the Site Manager.

Assumptions
-----------

Site Visitor has logged into the CMF (see :doc:`LoginAsMember`).

Procedure
---------

1. Click the 'Preferences' link in your top user actions bar.

2. On the personalization form, you have the option of modifying the
   following:

  **E-mail address** --
    your contact email address, used to send you your password if you forget
    it. The site administrator may also use this email to contact you when
    necessary.

  **Listing status (off/on)** --
    determines if you're login name is visible to other members when they
    select the 'members' link from the navigation bar.

  **Skin** --
    The 'look and feel' skin which is applied around the content of the site.
    The skin affects your 'view' while navigating the site.

3. Update these preferences as desired and select the change button.

4. The system will save your preferences and redisplay the
   personalization form with the a message stating that your
   preferences have been changed.
